@@ -6,7 +6,7 @@ package BSON::Double;
 # ABSTRACT: BSON type wrapper for Double
 
 use version;
-our $VERSION = 'v0.999.2'; # TRIAL
+our $VERSION = 'v0.999.3'; # TRIAL
 
 use Carp;
 
@@ -44,9 +44,13 @@ sub BUILD {
 #pod
 #pod =cut
 
+my $win32_specials = qr/-?1.\#IN[DF]/i;
+my $unix_specials = qr/-?(?:inf|nan)/i;
+my $illegal = $^O eq 'MSWin32' && $] lt "5.022" ? qr/^$win32_specials/ : qr/^$unix_specials/;
+
 sub TO_JSON {
     my $copy = "$_[0]->{value}"; # avoid changing value to PVNV
-    return $_[0]->{value}/1.0 unless $copy =~ /^(?:Inf|-Inf|NaN)/i;
+    return $_[0]->{value}/1.0 unless $copy =~ $illegal;
 
     croak( "The value '$copy' is illegal in JSON" );
 }
@@ -88,7 +92,7 @@ BSON::Double - BSON type wrapper for Double
 
 =head1 VERSION
 
-version v0.999.2
+version v0.999.3
 
 =head1 SYNOPSIS
 
